==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/spellchecker/translations/spellchecker_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Misspelled Words Marking Options</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Bold</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Italic</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Underline</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Spell Checker Options</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignore case</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Spelling Suggestions Options</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Show suggestions</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Maximum number of suggested words</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Spelling</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Could not find dictionary for %1 language.</translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Move to &apos;Checked&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Available languages</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Move to &apos;Available languages&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Checked</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/spellchecker/translations/spellchecker_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Misspelled Words Marking Options</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Bold</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Italic</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Underline</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Spell Checker Options</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignore case</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Spelling Suggestions Options</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Show suggestions</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Maximum number of suggested words</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Spelling</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Could not find dictionary for %1 language.</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>SpellcheckerConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation type="unfinished">Move to &apos;Checked&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation type="unfinished">Available languages</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation type="unfinished">Move to &apos;Available languages&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation type="unfinished">Checked</translation>
    </message>
</context>
</TS>
